@@ -1,10 +1,10 @@
-library(precrec)
+#' @importFrom precrec
 
 context("MM 2: Join datasets")
 # Test .join_datasets(..., efunc_vtype, efunc_nrow, byrow, chklen)
 
 test_that(".join_datasets() returns a list", {
-  cdat <- .join_datasets(c(0))
+  cdat <- .join_datasets(0)
 
   expect_true(is.list(cdat))
 })
@@ -15,11 +15,11 @@ test_that("'...' must be specified", {
 })
 
 test_that("'efunc_vtype' must be a function with 1 argument", {
-  expect_error(.join_datasets(c(0), efunc_vtype = function(a1) TRUE), NA)
+  expect_error(.join_datasets(0, efunc_vtype = function(a1) TRUE), NA)
 
   expect_err_msg <- function(efunc_vtype) {
     err_msg <- "efunc_vtype must be a function with 1 argument"
-    eval(bquote(expect_error(.join_datasets(c(0), efunc_vtype = efunc_vtype),
+    eval(bquote(expect_error(.join_datasets(0, efunc_vtype = efunc_vtype),
                              err_msg)))
   }
 
@@ -28,11 +28,11 @@ test_that("'efunc_vtype' must be a function with 1 argument", {
 })
 
 test_that("'efunc_nrow' must be a function with 2 arguments", {
-  expect_error(.join_datasets(c(0), efunc_nrow = function(a1, a2) TRUE), NA)
+  expect_error(.join_datasets(0, efunc_nrow = function(a1, a2) TRUE), NA)
 
   expect_err_msg <- function(efunc_nrow) {
     err_msg <- "efunc_nrow must be a function with 2 arguments"
-    eval(bquote(expect_error(.join_datasets(c(0), efunc_nrow = efunc_nrow),
+    eval(bquote(expect_error(.join_datasets(0, efunc_nrow = efunc_nrow),
                              err_msg)))
   }
 
@@ -41,12 +41,12 @@ test_that("'efunc_nrow' must be a function with 2 arguments", {
 })
 
 test_that("'byrow' should be TRUE or FALSE", {
-  expect_error(.join_datasets(c(0), byrow = TRUE), NA)
-  expect_error(.join_datasets(c(0), byrow = FALSE), NA)
+  expect_error(.join_datasets(0, byrow = TRUE), NA)
+  expect_error(.join_datasets(0, byrow = FALSE), NA)
 
   expect_err_msg <- function(err_msg, byrow) {
 
-    eval(bquote(expect_error(.join_datasets(c(0), byrow = byrow), err_msg)))
+    eval(bquote(expect_error(.join_datasets(0, byrow = byrow), err_msg)))
   }
 
   err_msg <- "byrow contains 1 missing values"
@@ -61,12 +61,12 @@ test_that("'byrow' should be TRUE or FALSE", {
 })
 
 test_that("'chklen' should be TRUE or FALSE", {
-  expect_error(.join_datasets(c(0), chklen = TRUE), NA)
-  expect_error(.join_datasets(c(0), chklen = FALSE), NA)
+  expect_error(.join_datasets(0, chklen = TRUE), NA)
+  expect_error(.join_datasets(0, chklen = FALSE), NA)
 
   expect_err_msg <- function(err_msg, chklen) {
 
-    eval(bquote(expect_error(.join_datasets(c(0), chklen = chklen), err_msg)))
+    eval(bquote(expect_error(.join_datasets(0, chklen = chklen), err_msg)))
   }
 
   err_msg <- "chklen contains 1 missing values"
@@ -88,7 +88,7 @@ test_that(".join_datasets() only accepts basic data types", {
 
   expect_err_msg(NULL)
 
-  cdat_vec <- .join_datasets(c(0))
+  cdat_vec <- .join_datasets(0)
   expect_true(is.list(cdat_vec))
 
   cdat_mat <- .join_datasets(matrix(0))
