@@ -1,4 +1,4 @@
-library(precrec)
+#' @importFrom precrec
 
 context("PL 1: Pipeline main")
 # Test .pmatch_mode(val)
@@ -43,7 +43,7 @@ pl1_create_mdat_ms <- function() {
   l3 <- c(1, 1, 0, 1)
   labels <- join_labels(l1, l2, l3)
 
-  mdat <- mmdata(scores, labels)
+  mmdata(scores, labels)
 }
 
 pl1_create_mdat_sm <- function() {
@@ -57,7 +57,7 @@ pl1_create_mdat_sm <- function() {
   l3 <- c(1, 1, 0, 1)
   labels <- join_labels(l1, l2, l3)
 
-  mdat <- mmdata(scores, labels, expd_first = "dsids")
+  mmdata(scores, labels, expd_first = "dsids")
 }
 
 pl1_create_mdat_mm <- function() {
@@ -73,8 +73,8 @@ pl1_create_mdat_mm <- function() {
   l4 <- c(1, 1, 0, 1)
   labels <- join_labels(l1, l2, l3, l4)
 
-  mdat <- mmdata(scores, labels, modnames = c("m1", "m2"), dsids = c(1, 2),
-                 expd_first = "modnames")
+  mmdata(scores, labels, modnames = c("m1", "m2"), dsids = c(1, 2),
+         expd_first = "modnames")
 }
 
 pl1_create_mdat_mm <- function() {
@@ -90,8 +90,8 @@ pl1_create_mdat_mm <- function() {
   l4 <- c(1, 1, 0, 1)
   labels <- join_labels(l1, l2, l3, l4)
 
-  mdat <- mmdata(scores, labels, modnames = c("m1", "m2"), dsids = c(1, 2),
-                 expd_first = "modnames")
+  mmdata(scores, labels, modnames = c("m1", "m2"), dsids = c(1, 2),
+         expd_first = "modnames")
 }
 
 test_that("pl_main() returns 'sscurves', 'sspoints', 'aucroc'", {
